Enum CInstruction

pub enum CInstruction {
Show 36 variants ADDI4SPN { dest: CIRegister, imm: CWideImmediate, }, FLD { dest: CFRegister, base: CIRegister, offset: CDImmediate, }, LW { dest: CIRegister, base: CIRegister, offset: CWImmediate, }, LD { dest: CIRegister, base: CIRegister, offset: CDImmediate, }, FSD { src: CFRegister, base: CIRegister, offset: CDImmediate, }, SW { src: CIRegister, base: CIRegister, offset: CWImmediate, }, SD { src: CIRegister, base: CIRegister, offset: CDImmediate, }, ADDI { dest: IRegister, imm: CIImmediate, }, ADDIW { dest: IRegister, imm: CIImmediate, }, LI { dest: IRegister, imm: CIImmediate, }, ADDI16SP { imm: C16SPImmediate, }, LUI { dest: IRegister, imm: CIImmediate, }, SRLI { dest: CIRegister, shamt: CShamt, }, SRAI { dest: CIRegister, shamt: CShamt, }, ANDI { dest: CIRegister, imm: CIImmediate, }, SUB { dest: CIRegister, src: CIRegister, }, XOR { dest: CIRegister, src: CIRegister, }, OR { dest: CIRegister, src: CIRegister, }, AND { dest: CIRegister, src: CIRegister, }, SUBW { dest: CIRegister, src: CIRegister, }, ADDW { dest: CIRegister, src: CIRegister, }, J { offset: CJImmediate, }, BEQZ { src: CIRegister, offset: CBImmediate, }, BNEZ { src: CIRegister, offset: CBImmediate, }, SLLI { dest: IRegister, shamt: CShamt, }, FLDSP { dest: FRegister, offset: CDSPImmediate, }, LWSP { dest: IRegister, offset: CWSPImmediate, }, LDSP { dest: IRegister, offset: CDSPImmediate, }, JR { src: IRegister, }, MV { dest: IRegister, src: IRegister, }, EBREAK, JALR { src: IRegister, }, ADD { dest: IRegister, src: IRegister, }, FSDSP { src: FRegister, offset: CSDSPImmediate, }, SWSP { src: IRegister, offset: CSWSPImmediate, }, SDSP { src: IRegister, offset: CSDSPImmediate, },
}

Variants



ADDI4SPN



FLD

Fields



LW

Fields



LD

Fields



FSD

Fields



SW

Fields



SD

Fields



ADDI

Fields



ADDIW

Fields



LI

Fields



ADDI16SP

Fields



LUI

Fields



SRLI

Fields

shamt: CShamt


SRAI

Fields

shamt: CShamt


ANDI

Fields



SUB

Fields



XOR

Fields



OR

Fields



AND

Fields



SUBW

Fields



ADDW

Fields



J

Fields



BEQZ

Fields



BNEZ

Fields



SLLI

Fields

shamt: CShamt


FLDSP

Fields



LWSP

Fields



LDSP

Fields



JR

Fields



MV

Fields



EBREAK



JALR

Fields



ADD

Fields



FSDSP

Fields



SWSP

Fields



SDSP

Fields

Implementations

Source

impl CInstruction

pub fn decode(instruction: u16) -> Result<Self, String>

Decodes a u16 into a CInstruction.

pub fn disassemble(instruction: &CInstruction) -> String

pub fn expand(&self) -> Instruction

Converts a compressed instruction into the corresponding 32-bit Instruction.

Note that C.JALR does not have exactly the same effect as the corresponding JALR as described in the manual:

Strictly speaking, C.JALR does not expand exactly to a base RVI instruction as the value added to the PC to form the link address is 2 rather than 4 as in the base ISA, but supporting both offsets of 2 and 4 bytes is only a very minor change to the base microarchitecture.

pub fn encode(instruction: &CInstruction) -> u16

Encodes a CInstruction into a u16.